==> jc-1.4.0.tar.gz: java__5fcup/runtime/Symbol.h <==
// public class java_cup.runtime.Symbol

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 413b2e03dcc84ee9 java__5fcup_runtime_Symbol

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_runtime_Symbol_H_
#define _JC_java__5fcup_runtime_Symbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_runtime_Symbol$sub_refs	_jc_java__5fcup_runtime_Symbol$sub_refs;
typedef struct _jc_java__5fcup_runtime_Symbol$sub_nonrefs	_jc_java__5fcup_runtime_Symbol$sub_nonrefs;
typedef struct _jc_java__5fcup_runtime_Symbol$refs	_jc_java__5fcup_runtime_Symbol$refs;
typedef struct _jc_java__5fcup_runtime_Symbol$nonrefs	_jc_java__5fcup_runtime_Symbol$nonrefs;
typedef struct _jc_java__5fcup_runtime_Symbol$object	_jc_java__5fcup_runtime_Symbol$object;

typedef const struct _jc_java__5fcup_runtime_Symbol$vmethods	_jc_java__5fcup_runtime_Symbol$vmethods;
typedef const struct _jc_java__5fcup_runtime_Symbol$vtable	_jc_java__5fcup_runtime_Symbol$vtable;
typedef const struct _jc_java__5fcup_runtime_Symbol$vtype	_jc_java__5fcup_runtime_Symbol$vtype;

// Constructors
extern void _jc_java__5fcup_runtime_Symbol$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint);
extern void _jc_java__5fcup_runtime_Symbol$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, jint);
extern void _jc_java__5fcup_runtime_Symbol$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, jint, jint);
extern void _jc_java__5fcup_runtime_Symbol$method$_init$974bc638e988ee24(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, jint, jint, struct _jc_java_lang_Object$object *);
extern void _jc_java__5fcup_runtime_Symbol$method$_init$964b4a8e45252143(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java__5fcup_runtime_Symbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_runtime_Symbol$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_runtime_Symbol$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *);
};

// Vtable
struct _jc_java__5fcup_runtime_Symbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_runtime_Symbol$vmethods	java__5fcup_runtime_Symbol;
};

// Vtype
struct _jc_java__5fcup_runtime_Symbol$vtype {
	_jc_type			type;
	_jc_java__5fcup_runtime_Symbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_runtime_Symbol$sub_refs {
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_java__5fcup_runtime_Symbol$refs {
    _jc_java__5fcup_runtime_Symbol$sub_refs	java__5fcup_runtime_Symbol;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_runtime_Symbol$sub_nonrefs {
	jint	sym;
	jint	parse__5fstate;
	jboolean	used__5fby__5fparser;
	jint	left;
	jint	right;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_runtime_Symbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_runtime_Symbol$sub_nonrefs	java__5fcup_runtime_Symbol;
};

// Object instance structure
struct _jc_java__5fcup_runtime_Symbol$object {
	_jc_java__5fcup_runtime_Symbol$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_runtime_Symbol$vtype	*vtype;
	_jc_java__5fcup_runtime_Symbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_runtime_Symbol$vtype _jc_java__5fcup_runtime_Symbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_runtime_Symbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_runtime_Symbol$class_object;

#endif	/* _JC_java__5fcup_runtime_Symbol_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/runtime/Symbol.h <==
// public class java_cup.runtime.Symbol

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 413b2e03dcc84ee9 java__5fcup_runtime_Symbol

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_runtime_Symbol_H_
#define _JC_java__5fcup_runtime_Symbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_runtime_Symbol$sub_refs	_jc_java__5fcup_runtime_Symbol$sub_refs;
typedef struct _jc_java__5fcup_runtime_Symbol$sub_nonrefs	_jc_java__5fcup_runtime_Symbol$sub_nonrefs;
typedef struct _jc_java__5fcup_runtime_Symbol$refs	_jc_java__5fcup_runtime_Symbol$refs;
typedef struct _jc_java__5fcup_runtime_Symbol$nonrefs	_jc_java__5fcup_runtime_Symbol$nonrefs;
typedef struct _jc_java__5fcup_runtime_Symbol$object	_jc_java__5fcup_runtime_Symbol$object;

typedef const struct _jc_java__5fcup_runtime_Symbol$vmethods	_jc_java__5fcup_runtime_Symbol$vmethods;
typedef const struct _jc_java__5fcup_runtime_Symbol$vtable	_jc_java__5fcup_runtime_Symbol$vtable;
typedef const struct _jc_java__5fcup_runtime_Symbol$vtype	_jc_java__5fcup_runtime_Symbol$vtype;

// Constructors
extern void _jc_java__5fcup_runtime_Symbol$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_runtime_Symbol$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_runtime_Symbol$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_runtime_Symbol$method$_init$974bc638e988ee24(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, jint, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_runtime_Symbol$method$_init$964b4a8e45252143(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java__5fcup_runtime_Symbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_runtime_Symbol$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_runtime_Symbol$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_runtime_Symbol$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_runtime_Symbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_runtime_Symbol$vmethods	java__5fcup_runtime_Symbol;
};

// Vtype
struct _jc_java__5fcup_runtime_Symbol$vtype {
	_jc_type			type;
	_jc_java__5fcup_runtime_Symbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_runtime_Symbol$sub_refs {
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_java__5fcup_runtime_Symbol$refs {
    _jc_java__5fcup_runtime_Symbol$sub_refs	java__5fcup_runtime_Symbol;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_runtime_Symbol$sub_nonrefs {
	jint	sym;
	jint	parse__5fstate;
	jboolean	used__5fby__5fparser;
	jint	left;
	jint	right;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_runtime_Symbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_runtime_Symbol$sub_nonrefs	java__5fcup_runtime_Symbol;
};

// Object instance structure
struct _jc_java__5fcup_runtime_Symbol$object {
	_jc_java__5fcup_runtime_Symbol$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_runtime_Symbol$vtype	*vtype;
	_jc_java__5fcup_runtime_Symbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_runtime_Symbol$vtype _jc_java__5fcup_runtime_Symbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_runtime_Symbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_runtime_Symbol$class_object;

#endif	/* _JC_java__5fcup_runtime_Symbol_H_ */
